@@ -7,7 +7,7 @@
 #  define VTKACCELERATORSVTKM_NO_EXPORT
 #else
 #  ifndef VTKACCELERATORSVTKM_EXPORT
-#    ifdef vtkAcceleratorsVTKm_EXPORTS
+#    ifdef AcceleratorsVTKm_EXPORTS
         /* We are building this library */
 #      define VTKACCELERATORSVTKM_EXPORT __attribute__((visibility("default")))
 #    else
@@ -23,16 +23,20 @@
 
 #ifndef VTKACCELERATORSVTKM_DEPRECATED
 #  define VTKACCELERATORSVTKM_DEPRECATED __attribute__ ((__deprecated__))
-#  define VTKACCELERATORSVTKM_DEPRECATED_EXPORT VTKACCELERATORSVTKM_EXPORT __attribute__ ((__deprecated__))
-#  define VTKACCELERATORSVTKM_DEPRECATED_NO_EXPORT VTKACCELERATORSVTKM_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define VTKACCELERATORSVTKM_NO_DEPRECATED
+#ifndef VTKACCELERATORSVTKM_DEPRECATED_EXPORT
+#  define VTKACCELERATORSVTKM_DEPRECATED_EXPORT VTKACCELERATORSVTKM_EXPORT VTKACCELERATORSVTKM_DEPRECATED
 #endif
 
-/* AutoInit dependencies.  */
-#include "vtkFiltersGeneralModule.h"
-
+#ifndef VTKACCELERATORSVTKM_DEPRECATED_NO_EXPORT
+#  define VTKACCELERATORSVTKM_DEPRECATED_NO_EXPORT VTKACCELERATORSVTKM_NO_EXPORT VTKACCELERATORSVTKM_DEPRECATED
 #endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef VTKACCELERATORSVTKM_NO_DEPRECATED
+#    define VTKACCELERATORSVTKM_NO_DEPRECATED
+#  endif
+#endif
+
+#endif /* VTKACCELERATORSVTKM_EXPORT_H */
