@@ -7,7 +7,7 @@
 #  define VTKCLIENTSERVER_NO_EXPORT
 #else
 #  ifndef VTKCLIENTSERVER_EXPORT
-#    ifdef vtkClientServer_EXPORTS
+#    ifdef ClientServer_EXPORTS
         /* We are building this library */
 #      define VTKCLIENTSERVER_EXPORT __attribute__((visibility("default")))
 #    else
@@ -23,15 +23,20 @@
 
 #ifndef VTKCLIENTSERVER_DEPRECATED
 #  define VTKCLIENTSERVER_DEPRECATED __attribute__ ((__deprecated__))
-#  define VTKCLIENTSERVER_DEPRECATED_EXPORT VTKCLIENTSERVER_EXPORT __attribute__ ((__deprecated__))
-#  define VTKCLIENTSERVER_DEPRECATED_NO_EXPORT VTKCLIENTSERVER_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define VTKCLIENTSERVER_NO_DEPRECATED
+#ifndef VTKCLIENTSERVER_DEPRECATED_EXPORT
+#  define VTKCLIENTSERVER_DEPRECATED_EXPORT VTKCLIENTSERVER_EXPORT VTKCLIENTSERVER_DEPRECATED
 #endif
 
-
-
+#ifndef VTKCLIENTSERVER_DEPRECATED_NO_EXPORT
+#  define VTKCLIENTSERVER_DEPRECATED_NO_EXPORT VTKCLIENTSERVER_NO_EXPORT VTKCLIENTSERVER_DEPRECATED
 #endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef VTKCLIENTSERVER_NO_DEPRECATED
+#    define VTKCLIENTSERVER_NO_DEPRECATED
+#  endif
+#endif
+
+#endif /* VTKCLIENTSERVER_EXPORT_H */
