@@ -7,7 +7,7 @@
 #  define VTKIOVISITBRIDGE_NO_EXPORT
 #else
 #  ifndef VTKIOVISITBRIDGE_EXPORT
-#    ifdef vtkIOVisItBridge_EXPORTS
+#    ifdef IOVisItBridge_EXPORTS
         /* We are building this library */
 #      define VTKIOVISITBRIDGE_EXPORT __attribute__((visibility("default")))
 #    else
@@ -23,15 +23,20 @@
 
 #ifndef VTKIOVISITBRIDGE_DEPRECATED
 #  define VTKIOVISITBRIDGE_DEPRECATED __attribute__ ((__deprecated__))
-#  define VTKIOVISITBRIDGE_DEPRECATED_EXPORT VTKIOVISITBRIDGE_EXPORT __attribute__ ((__deprecated__))
-#  define VTKIOVISITBRIDGE_DEPRECATED_NO_EXPORT VTKIOVISITBRIDGE_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define VTKIOVISITBRIDGE_NO_DEPRECATED
+#ifndef VTKIOVISITBRIDGE_DEPRECATED_EXPORT
+#  define VTKIOVISITBRIDGE_DEPRECATED_EXPORT VTKIOVISITBRIDGE_EXPORT VTKIOVISITBRIDGE_DEPRECATED
 #endif
 
-
-
+#ifndef VTKIOVISITBRIDGE_DEPRECATED_NO_EXPORT
+#  define VTKIOVISITBRIDGE_DEPRECATED_NO_EXPORT VTKIOVISITBRIDGE_NO_EXPORT VTKIOVISITBRIDGE_DEPRECATED
 #endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef VTKIOVISITBRIDGE_NO_DEPRECATED
+#    define VTKIOVISITBRIDGE_NO_DEPRECATED
+#  endif
+#endif
+
+#endif /* VTKIOVISITBRIDGE_EXPORT_H */
