@@ -7,7 +7,7 @@
 #  define VTKPVCLIENTSERVERCOREDEFAULT_NO_EXPORT
 #else
 #  ifndef VTKPVCLIENTSERVERCOREDEFAULT_EXPORT
-#    ifdef vtkPVClientServerCoreDefault_EXPORTS
+#    ifdef ClientServerCoreDefault_EXPORTS
         /* We are building this library */
 #      define VTKPVCLIENTSERVERCOREDEFAULT_EXPORT __attribute__((visibility("default")))
 #    else
@@ -23,17 +23,20 @@
 
 #ifndef VTKPVCLIENTSERVERCOREDEFAULT_DEPRECATED
 #  define VTKPVCLIENTSERVERCOREDEFAULT_DEPRECATED __attribute__ ((__deprecated__))
-#  define VTKPVCLIENTSERVERCOREDEFAULT_DEPRECATED_EXPORT VTKPVCLIENTSERVERCOREDEFAULT_EXPORT __attribute__ ((__deprecated__))
-#  define VTKPVCLIENTSERVERCOREDEFAULT_DEPRECATED_NO_EXPORT VTKPVCLIENTSERVERCOREDEFAULT_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define VTKPVCLIENTSERVERCOREDEFAULT_NO_DEPRECATED
+#ifndef VTKPVCLIENTSERVERCOREDEFAULT_DEPRECATED_EXPORT
+#  define VTKPVCLIENTSERVERCOREDEFAULT_DEPRECATED_EXPORT VTKPVCLIENTSERVERCOREDEFAULT_EXPORT VTKPVCLIENTSERVERCOREDEFAULT_DEPRECATED
 #endif
 
-/* AutoInit dependencies.  */
-#include "vtkPVClientServerCoreRenderingModule.h"
-#include "vtkPVVTKExtensionsDefaultModule.h"
-
+#ifndef VTKPVCLIENTSERVERCOREDEFAULT_DEPRECATED_NO_EXPORT
+#  define VTKPVCLIENTSERVERCOREDEFAULT_DEPRECATED_NO_EXPORT VTKPVCLIENTSERVERCOREDEFAULT_NO_EXPORT VTKPVCLIENTSERVERCOREDEFAULT_DEPRECATED
 #endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef VTKPVCLIENTSERVERCOREDEFAULT_NO_DEPRECATED
+#    define VTKPVCLIENTSERVERCOREDEFAULT_NO_DEPRECATED
+#  endif
+#endif
+
+#endif /* VTKPVCLIENTSERVERCOREDEFAULT_EXPORT_H */
