@@ -7,7 +7,7 @@
 #  define VTKPVSERVERIMPLEMENTATIONCORE_NO_EXPORT
 #else
 #  ifndef VTKPVSERVERIMPLEMENTATIONCORE_EXPORT
-#    ifdef vtkPVServerImplementationCore_EXPORTS
+#    ifdef ServerImplementationCore_EXPORTS
         /* We are building this library */
 #      define VTKPVSERVERIMPLEMENTATIONCORE_EXPORT __attribute__((visibility("default")))
 #    else
@@ -23,16 +23,20 @@
 
 #ifndef VTKPVSERVERIMPLEMENTATIONCORE_DEPRECATED
 #  define VTKPVSERVERIMPLEMENTATIONCORE_DEPRECATED __attribute__ ((__deprecated__))
-#  define VTKPVSERVERIMPLEMENTATIONCORE_DEPRECATED_EXPORT VTKPVSERVERIMPLEMENTATIONCORE_EXPORT __attribute__ ((__deprecated__))
-#  define VTKPVSERVERIMPLEMENTATIONCORE_DEPRECATED_NO_EXPORT VTKPVSERVERIMPLEMENTATIONCORE_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define VTKPVSERVERIMPLEMENTATIONCORE_NO_DEPRECATED
+#ifndef VTKPVSERVERIMPLEMENTATIONCORE_DEPRECATED_EXPORT
+#  define VTKPVSERVERIMPLEMENTATIONCORE_DEPRECATED_EXPORT VTKPVSERVERIMPLEMENTATIONCORE_EXPORT VTKPVSERVERIMPLEMENTATIONCORE_DEPRECATED
 #endif
 
-/* AutoInit dependencies.  */
-#include "vtkPVClientServerCoreCoreModule.h"
-
+#ifndef VTKPVSERVERIMPLEMENTATIONCORE_DEPRECATED_NO_EXPORT
+#  define VTKPVSERVERIMPLEMENTATIONCORE_DEPRECATED_NO_EXPORT VTKPVSERVERIMPLEMENTATIONCORE_NO_EXPORT VTKPVSERVERIMPLEMENTATIONCORE_DEPRECATED
 #endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef VTKPVSERVERIMPLEMENTATIONCORE_NO_DEPRECATED
+#    define VTKPVSERVERIMPLEMENTATIONCORE_NO_DEPRECATED
+#  endif
+#endif
+
+#endif /* VTKPVSERVERIMPLEMENTATIONCORE_EXPORT_H */
