@@ -5,148 +5,113 @@ from __future__ import absolute_import
 
 # --------------------------------------
 from .vtkCommonCore import *
+from .vtkWebCore import *
 from .vtkCommonMath import *
-from .vtkCommonMisc import *
-from .vtkCommonSystem import *
 from .vtkCommonTransforms import *
 from .vtkCommonDataModel import *
 from .vtkCommonExecutionModel import *
-from .vtkFiltersCore import *
 from .vtkIOCore import *
+from .vtkIOImage import *
 from .vtkIOXMLParser import *
 from .vtkIOXML import *
-from .vtkIOLegacy import *
-from .vtkParallelCore import *
-from .vtkFiltersAMR import *
-from .vtkCommonComputationalGeometry import *
-from .vtkFiltersGeneral import *
-from .vtkImagingCore import *
-from .vtkImagingFourier import *
-from .vtkFiltersStatistics import *
-from .vtkFiltersExtraction import *
-from .vtkFiltersGeometry import *
-from .vtkFiltersSources import *
-from .vtkFiltersFlowPaths import *
-from .vtkIOImage import *
-from .vtkIOGeometry import *
-from .vtkImagingHybrid import *
-from .vtkCommonColor import *
+from .vtkCommonMisc import *
+from .vtkFiltersCore import *
 from .vtkRenderingCore import *
-from .vtkImagingMath import *
-from .vtkRenderingOpenGL2 import *
-from .vtkRenderingVolume import *
-from .vtkRenderingVolumeOpenGL2 import *
-from .vtkInteractionStyle import *
-from .vtkFiltersModeling import *
-from .vtkFiltersParallel import *
-from .vtkFiltersProgrammable import *
-from .vtkPythonInterpreter import *
-from .vtkClientServer import *
-from .vtkPVCommon import *
-from .vtkPVVTKExtensionsCore import *
-from .vtkPVVTKExtensionsSIL import *
-from .vtkParallelMPI import *
-from .vtkPVClientServerCoreCore import *
-from .vtkPVServerImplementationCore import *
-from .vtkPVServerManagerCore import *
-from .vtkIOMovie import *
-from .vtkIOFFMPEG import *
-from .vtkInfovisCore import *
-from .vtkIOInfovis import *
-from .vtkAcceleratorsVTKm import *
-from .vtkDomainsChemistry import *
-from .vtkRenderingFreeType import *
 from .vtkRenderingContext2D import *
-from .vtkChartsCore import *
-from .vtkFiltersParallelFlowPaths import *
-from .vtkFiltersParallelStatistics import *
-from .vtkIOEnSight import *
-from .vtkIOImport import *
-from .vtkIOMPIImage import *
-from .vtkIOPLY import *
-from .vtkIONetCDF import *
-from .vtkIOParallel import *
+from .vtkRenderingFreeType import *
+from .vtkIOExport import *
+from .vtkWebGLExporter import *
+from .vtkFiltersGeneral import *
+from .vtkFiltersSources import *
+from .vtkInteractionWidgets import *
+from .vtkViewsCore import *
+from .vtkViewsContext2D import *
+from .vtkTestingRendering import *
+from .vtkRenderingOpenGL2 import *
+from .vtkRenderingSceneGraph import *
+from .vtkRenderingVolume import *
+from .vtkRenderingRayTracing import *
+from .vtkImagingCore import *
+from .vtkImagingMath import *
+from .vtkRenderingVolumeOpenGL2 import *
+from .vtkRenderingVolumeAMR import *
+from .vtkRenderingParallel import *
+from .vtkRenderingMatplotlib import *
+from .vtkRenderingLabel import *
+from .vtkRenderingLICOpenGL2 import *
+from .vtkRenderingContextOpenGL2 import *
+from .vtkParallelMPI4Py import *
+from .vtkIOLegacy import *
+from .vtkIOXdmf2 import *
+from .vtkIOVeraOut import *
+from .vtkIOVPIC import *
+from .vtkIOTecplotTable import *
+from .vtkIOTRUCHAS import *
+from .vtkIOSegY import *
+from .vtkIOParallelXML import *
+from .vtkIOParallelNetCDF import *
+from .vtkIOLSDyna import *
+from .vtkIOParallelLSDyna import *
 from .vtkIOExodus import *
 from .vtkIOParallelExodus import *
-from .vtkIOParallelXML import *
-from .vtkImagingSources import *
+from .vtkIOPLY import *
+from .vtkIOPDAL import *
+from .vtkIOGeometry import *
+from .vtkIONetCDF import *
+from .vtkIOParallel import *
+from .vtkIOMPIImage import *
+from .vtkIOInfovis import *
+from .vtkIOImport import *
+from .vtkIOH5part import *
+from .vtkFiltersGeometry import *
 from .vtkFiltersHybrid import *
+from .vtkIOMovie import *
+from .vtkIOVideo import *
+from .vtkIOFFMPEG import *
+from .vtkRenderingGL2PSOpenGL2 import *
+from .vtkIOExportGL2PS import *
+from .vtkIOEnSight import *
+from .vtkIOAsynchronous import *
+from .vtkIOAMR import *
+from .vtkIOGDAL import *
+from .vtkGeovisGDAL import *
+from .vtkCommonColor import *
+from .vtkImagingSources import *
+from .vtkInfovisCore import *
+from .vtkInteractionStyle import *
+from .vtkGeovisCore import *
+from .vtkInfovisLayout import *
 from .vtkImagingColor import *
 from .vtkImagingGeneral import *
 from .vtkRenderingAnnotation import *
-from .vtkInteractionWidgets import *
-from .vtkFiltersGeneric import *
-from .vtkFiltersHyperTree import *
-from .vtkFiltersParallelMPI import *
-from .vtkRenderingGL2PSOpenGL2 import *
-from .vtkIOExport import *
-from .vtkIOExportOpenGL2 import *
-from .vtkRenderingContextOpenGL2 import *
-from .vtkRenderingMatplotlib import *
-from .vtkRenderingSceneGraph import *
-from .vtkRenderingVolumeAMR import *
-from .vtkRenderingOSPRay import *
-from .vtkRenderingParallel import *
-from .vtkPVVTKExtensionsRendering import *
-from .vtkPVVTKExtensionsDefault import *
-from .vtkRenderingLabel import *
-from .vtkViewsCore import *
-from .vtkViewsContext2D import *
-from .vtkPVClientServerCoreRendering import *
-from .vtkPVClientServerCoreDefault import *
-from .vtkPVServerImplementationRendering import *
-from .vtkPVServerManagerRendering import *
-from .vtkTestingRendering import *
-from .vtkPVServerManagerDefault import *
-from .vtkPVAnimation import *
-from .vtkDomainsChemistryOpenGL2 import *
-from .vtkDomainsParallelChemistry import *
-from .vtkFiltersParallelDIY2 import *
-from .vtkFiltersParallelGeometry import *
-from .vtkFiltersImaging import *
-from .vtkFiltersParallelImaging import *
-from .vtkFiltersVerdict import *
-from .vtkFiltersParallelVerdict import *
-from .vtkFiltersPython import *
+from .vtkImagingHybrid import *
 from .vtkFiltersTexture import *
-from .vtkIOAMR import *
-from .vtkIOAsynchronous import *
-from .vtkIOGDAL import *
-from .vtkIOMPIParallel import *
-from .vtkIOMotionFX import *
-from .vtkIOPDAL import *
-from .vtkIOLSDyna import *
-from .vtkIOParallelLSDyna import *
-from .vtkIOParallelNetCDF import *
-from .vtkIOSegY import *
-from .vtkIOTRUCHAS import *
-from .vtkIOTecplotTable import *
-from .vtkIOVPIC import *
-from .vtkIOVeraOut import *
-from .vtkIOVisItBridge import *
-from .vtkIOXdmf2 import *
-from .vtkImagingMorphological import *
-from .vtkInteractionImage import *
-from .vtkPVCinemaReader import *
-from .vtkPVPythonAlgorithm import *
-from .vtkPVVTKExtensionsCGNSReader import *
-from .vtkPVVTKExtensionsCGNSWriter import *
-from .vtkPVVTKExtensionsH5PartReader import *
+from .vtkFiltersPython import *
+from .vtkFiltersProgrammable import *
+from .vtkFiltersModeling import *
 from .vtkFiltersPoints import *
-from .vtkPVVTKExtensionsPoints import *
-from .vtkParallelMPI4Py import *
-from .vtkRenderingLICOpenGL2 import *
-from .vtkRenderingLOD import *
-from .vtkRenderingParallelLIC import *
-from .vtkPVServerManagerApplication import *
-from .vtkInfovisLayout import *
-from .vtkGeovisCore import *
-from .vtkGeovisGDAL import *
-from .vtkPVCatalyst import *
-from .vtkWebGLExporter import *
-from .vtkWebCore import *
-from .vtkParaViewWebCore import *
-# --------------------------------------
+from .vtkFiltersVerdict import *
+from .vtkFiltersStatistics import *
+from .vtkFiltersParallelStatistics import *
+from .vtkCommonSystem import *
+from .vtkFiltersExtraction import *
+from .vtkFiltersParallel import *
+from .vtkParallelCore import *
+from .vtkParallelMPI import *
+from .vtkFiltersParallelGeometry import *
+from .vtkFiltersFlowPaths import *
+from .vtkFiltersParallelFlowPaths import *
+from .vtkFiltersParallelDIY2 import *
+from .vtkFiltersHyperTree import *
+from .vtkFiltersGeneric import *
+from .vtkFiltersAMR import *
+from .vtkFiltersParallelMPI import *
+from .vtkDomainsChemistry import *
+from .vtkChartsCore import *
+from .vtkImagingFourier import *
+from .vtkAcceleratorsVTKm import *
+from .vtkCommonComputationalGeometry import *
+
 
 # useful macro for getting type names
 from .util.vtkConstants import vtkImageScalarTypeNameMacro
